nxp-pac

Crates

git

Versions

mcxa577

Flavors

RamXen

Struct RamXen 

#[repr(transparent)]
pub struct RamXen(pub u32);
RAM XEN Control

Tuple Fields

0: u32

Implementations

Source

impl RamXen

pub const fn ramx0_xen(&self) -> bool

RAMX0-3 Execute permission control.

pub const fn set_ramx0_xen(&mut self, val: bool)

RAMX0-3 Execute permission control.

pub const fn ramx1_xen(&self) -> bool

RAMXn (excepts RAMA0-3) Execute permission control.

pub const fn set_ramx1_xen(&mut self, val: bool)

RAMXn (excepts RAMA0-3) Execute permission control.

pub const fn rama0_xen(&self) -> bool

RAMA0 Execute permission control.

pub const fn set_rama0_xen(&mut self, val: bool)

RAMA0 Execute permission control.

pub const fn rama1_xen(&self) -> bool

RAMAx (excepts RAMA0) Execute permission control.

pub const fn set_rama1_xen(&mut self, val: bool)

RAMAx (excepts RAMA0) Execute permission control.

pub const fn ramb_xen(&self) -> bool

RAMBx Execute permission control.

pub const fn set_ramb_xen(&mut self, val: bool)

RAMBx Execute permission control.

pub const fn lock(&self) -> bool

This 1-bit field provides a mechanism to limit writes to this register (and RAM_XEN_DP) to protect its contents. Once set, this bit remains asserted until a system reset.

pub const fn set_lock(&mut self, val: bool)

This 1-bit field provides a mechanism to limit writes to this register (and RAM_XEN_DP) to protect its contents. Once set, this bit remains asserted until a system reset.